package com.ruoyi.szxc.service.impl;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.szxc.domain.SzxcPublicActivily;
import com.ruoyi.szxc.mapper.SzxcPublicActivilyMapper;
import com.ruoyi.szxc.service.ISzxcPublicActivilyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * 公益活动Service业务层处理
 * 
 * @author hs
 * @date 2024-03-20
 */
@Service
public class SzxcPublicActivilyServiceImpl implements ISzxcPublicActivilyService 
{
    @Autowired
    private SzxcPublicActivilyMapper szxcPublicActivilyMapper;

    /**
     * 查询公益活动
     * 
     * @param id 公益活动主键
     * @return 公益活动
     */
    @Override
    public SzxcPublicActivily selectSzxcPublicActivilyById(Long id)
    {
        return szxcPublicActivilyMapper.selectSzxcPublicActivilyById(id);
    }

    /**
     * 查询公益活动列表
     * 
     * @param szxcPublicActivily 公益活动
     * @return 公益活动
     */
    @Override
    @DataScope(deptAlias = "p")
    public List<SzxcPublicActivily> selectSzxcPublicActivilyList(SzxcPublicActivily szxcPublicActivily)
    {
        return szxcPublicActivilyMapper.selectSzxcPublicActivilyList(szxcPublicActivily);
    }

    /**
     * 新增公益活动
     * 
     * @param szxcPublicActivily 公益活动
     * @return 结果
     */
    @Override
    public int insertSzxcPublicActivily(SzxcPublicActivily szxcPublicActivily)
    {
        szxcPublicActivily.setCreateTime(DateUtils.getNowDate());
        return szxcPublicActivilyMapper.insertSzxcPublicActivily(szxcPublicActivily);
    }

    /**
     * 修改公益活动
     * 
     * @param szxcPublicActivily 公益活动
     * @return 结果
     */
    @Override
    public int updateSzxcPublicActivily(SzxcPublicActivily szxcPublicActivily)
    {
        szxcPublicActivily.setUpdateTime(DateUtils.getNowDate());
        return szxcPublicActivilyMapper.updateSzxcPublicActivily(szxcPublicActivily);
    }

    /**
     * 批量删除公益活动
     * 
     * @param ids 需要删除的公益活动主键
     * @return 结果
     */
    @Override
    public int deleteSzxcPublicActivilyByIds(Long[] ids)
    {
        return szxcPublicActivilyMapper.deleteSzxcPublicActivilyByIds(ids);
    }

    @Override
    public List<Map<String, Object>> getActiveData() {
        return szxcPublicActivilyMapper.getActiveData();
    }

    /**
     * 删除公益活动信息
     * 
     * @param id 公益活动主键
     * @return 结果
     */
    @Override
    public int deleteSzxcPublicActivilyById(Long id)
    {
        return szxcPublicActivilyMapper.deleteSzxcPublicActivilyById(id);
    }
}
